@@ -6,10 +6,8 @@ test "$PKG_NAME" || PKG_NAME=Package
 test "$srcdir" || srcdir=.
 
 # default version requirements ...
-test "$REQUIRED_AUTOCONF_VERSION" || REQUIRED_AUTOCONF_VERSION=2.53
-test "$REQUIRED_AUTOMAKE_VERSION" || REQUIRED_AUTOMAKE_VERSION=1.9
-test "$REQUIRED_LIBTOOL_VERSION" || REQUIRED_LIBTOOL_VERSION=1.4.3
-test "$REQUIRED_GETTEXT_VERSION" || REQUIRED_GETTEXT_VERSION=0.10.40
+test "$REQUIRED_AUTOMAKE_VERSION" || REQUIRED_AUTOMAKE_VERSION=1.11.2
+test "$REQUIRED_AUTORECONF_VERSION" || REQUIRED_AUTORECONF_VERSION=2.53
 test "$REQUIRED_GLIB_GETTEXT_VERSION" || REQUIRED_GLIB_GETTEXT_VERSION=2.2.0
 test "$REQUIRED_INTLTOOL_VERSION" || REQUIRED_INTLTOOL_VERSION=0.25
 test "$REQUIRED_PKG_CONFIG_VERSION" || REQUIRED_PKG_CONFIG_VERSION=0.14.0
@@ -36,7 +34,7 @@ case `echo -n x` in
 esac
 
 # some terminal codes ...
-if tty < /dev/null 1>/dev/null 2>&1; then
+if tty 1>/dev/null 2>&1; then
     boldface="`tput bold 2>/dev/null`"
     normal="`tput sgr0 2>/dev/null`"
 else
@@ -59,7 +57,7 @@ compare_versions() {
     ch_min_version=$1
     ch_actual_version=$2
     ch_status=0
-    IFS="${IFS=         }"; ch_save_IFS="$IFS"; IFS="."
+    IFS="${IFS=	 }"; ch_save_IFS="$IFS"; IFS="."
     set $ch_actual_version
     for ch_min in $ch_min_version; do
         ch_cur=`echo $1 | sed 's/[^0-9].*$//'`; shift # remove letter suffixes
@@ -82,6 +80,7 @@ version_check() {
     vc_min_version=$4
     vc_source=$5
     vc_status=1
+    local ${vc_variable}_VERSION
 
     vc_checkprog=`eval echo "\\$$vc_variable"`
     if [ -n "$vc_checkprog" ]; then
@@ -89,12 +88,7 @@ version_check() {
 	return 0
     fi
 
-    if test "x$vc_package" = "xautomake" -a "x$vc_min_version" = "x1.4"; then
-	vc_comparator="="
-    else
-	vc_comparator=">="
-    fi
-    printbold "checking for $vc_package $vc_comparator $vc_min_version..."
+    printbold "checking for $vc_package >= $vc_min_version..."
     for vc_checkprog in $vc_checkprogs; do
 	echo $ECHO_N "  testing $vc_checkprog... " $ECHO_C
 	if $vc_checkprog --version < /dev/null > /dev/null 2>&1; then
@@ -115,7 +109,7 @@ version_check() {
 	fi
     done
     if [ "$vc_status" != 0 ]; then
-	printerr "***Error***: You must have $vc_package $vc_comparator $vc_min_version installed"
+	printerr "***Error***: You must have $vc_package >= $vc_min_version installed"
 	printerr "  to build $PKG_NAME.  Download the appropriate package for"
 	printerr "  from your distribution or get the source tarball at"
         printerr "    $vc_source"
@@ -159,23 +153,22 @@ print_m4macros_error() {
     printerr "***Error***: some autoconf macros required to build $PKG_NAME"
     printerr "  were not found in your aclocal path, or some forbidden"
     printerr "  macros were found.  Perhaps you need to adjust your"
-    printerr "  ACLOCAL_FLAGS?"
+    printerr "  ACLOCAL_PATH?"
     printerr
 }
 
 # Usage:
 #     check_m4macros
 # Checks that all the requested macro files are in the aclocal macro path
-# Uses REQUIRED_M4MACROS and ACLOCAL variables.
+# Uses REQUIRED_M4MACROS and ACLOCAL_PATH variables.
 check_m4macros() {
     # construct list of macro directories
-    cm_macrodirs=`$ACLOCAL --print-ac-dir`
+    cm_macrodirs=`aclocal --print-ac-dir`
     # aclocal also searches a version specific dir, eg. /usr/share/aclocal-1.9
     # but it contains only Automake's own macros, so we can ignore it.
 
-    # Read the dirlist file, supported by Automake >= 1.7.
-    # If AUTOMAKE was defined, no version was detected.
-    if [ -z "$AUTOMAKE_VERSION" ] || compare_versions 1.7 $AUTOMAKE_VERSION && [ -s $cm_macrodirs/dirlist ]; then
+    # Read the dirlist file
+    if [ -s $cm_macrodirs/dirlist ]; then
 	cm_dirlist=`sed 's/[ 	]*#.*//;/^$/d' $cm_macrodirs/dirlist`
 	if [ -n "$cm_dirlist" ] ; then
 	    for cm_dir in $cm_dirlist; do
@@ -186,15 +179,12 @@ check_m4macros() {
 	fi
     fi
 
-    # Parse $ACLOCAL_FLAGS
-    set - $ACLOCAL_FLAGS
-    while [ $# -gt 0 ]; do
-	if [ "$1" = "-I" ]; then
-	    add_to_cm_macrodirs "$2"
-	    shift
-	fi
-	shift
+    # Parse $ACLOCAL_PATH
+    IFS="${IFS=	 }"; save_IFS="$IFS"; IFS=":"
+    for dir in ${ACLOCAL_PATH}; do
+	add_to_cm_macrodirs "$dir"
     done
+    IFS="$save_IFS"
 
     cm_status=0
     if [ -n "$REQUIRED_M4MACROS" ]; then
@@ -256,8 +246,6 @@ check_m4macros() {
 # try to catch the case where the macros2/ directory hasn't been cleared out.
 forbid_m4macro gnome-cxx-check.m4
 
-want_libtool=false
-want_gettext=false
 want_glib_gettext=false
 want_intltool=false
 want_pkg_config=false
@@ -265,6 +253,12 @@ want_gtk_doc=false
 want_gnome_doc_utils=false
 want_maintainer_mode=false
 
+version_check automake AUTOMAKE automake $REQUIRED_AUTOMAKE_VERSION \
+    "http://ftp.gnu.org/pub/gnu/automake/automake-$REQUIRED_AUTOMAKE_VERSION.tar.xz"
+
+version_check autoreconf AUTORECONF autoreconf $REQUIRED_AUTORECONF_VERSION \
+    "http://ftp.gnu.org/pub/gnu/autoconf/autoconf-$REQUIRED_AUTORECONF_VERSION.tar.xz"
+
 find_configure_files() {
     configure_ac=
     if test -f "$1/configure.ac"; then
@@ -274,7 +268,6 @@ find_configure_files() {
     fi
     if test "x$configure_ac" != x; then
 	echo "$configure_ac"
-	# TODO We have not detected the right autoconf yet!
 	autoconf -t 'AC_CONFIG_SUBDIRS:$1' "$configure_ac" | while read dir; do
 	    find_configure_files "$1/$dir"
 	done
@@ -289,13 +282,6 @@ for configure_ac in $configure_files; do
 	echo skipping $dirname -- flagged as no auto-gen
 	continue
     fi
-    if grep "^A[CM]_PROG_LIBTOOL" $configure_ac >/dev/null ||
-       grep "^LT_INIT" $configure_ac >/dev/null; then
-	want_libtool=true
-    fi
-    if grep "^AM_GNU_GETTEXT" $configure_ac >/dev/null; then
-	want_gettext=true
-    fi
     if grep "^AM_GLIB_GNU_GETTEXT" $configure_ac >/dev/null; then
 	want_glib_gettext=true
     fi
@@ -322,6 +308,10 @@ for configure_ac in $configure_files; do
         require_m4macro yelp.m4
     fi
 
+    if grep "^APPDATA_XML" $configure_ac >/dev/null; then
+        require_m4macro appdata-xml.m4
+    fi
+
     # check to make sure gnome-common macros can be found ...
     if grep "^GNOME_COMMON_INIT" $configure_ac >/dev/null ||
        grep "^GNOME_DEBUG_CHECK" $configure_ac >/dev/null ||
@@ -337,40 +327,6 @@ for configure_ac in $configure_files; do
     fi
 done
 
-#tell Mandrake autoconf wrapper we want autoconf 2.5x, not 2.13
-WANT_AUTOCONF_2_5=1
-export WANT_AUTOCONF_2_5
-version_check autoconf AUTOCONF 'autoconf2.50 autoconf autoconf-2.53' $REQUIRED_AUTOCONF_VERSION \
-    "http://ftp.gnu.org/pub/gnu/autoconf/autoconf-$REQUIRED_AUTOCONF_VERSION.tar.gz"
-AUTOHEADER=`echo $AUTOCONF | sed s/autoconf/autoheader/`
-
-case $REQUIRED_AUTOMAKE_VERSION in
-    1.4*) automake_progs="automake-1.4" ;;
-    1.5*) automake_progs="automake-1.12 automake-1.11 automake-1.10 automake-1.9 automake-1.8 automake-1.7 automake-1.6 automake-1.5" ;;
-    1.6*) automake_progs="automake-1.12 automake-1.11 automake-1.10 automake-1.9 automake-1.8 automake-1.7 automake-1.6" ;;
-    1.7*) automake_progs="automake-1.12 automake-1.11 automake-1.10 automake-1.9 automake-1.8 automake-1.7" ;;
-    1.8*) automake_progs="automake-1.12 automake-1.11 automake-1.10 automake-1.9 automake-1.8" ;;
-    1.9*) automake_progs="automake-1.12 automake-1.11 automake-1.10 automake-1.9" ;;
-    1.10*) automake_progs="automake-1.12 automake-1.11 automake-1.10" ;;
-    1.11*) automake_progs="automake-1.12 automake-1.11" ;;
-    1.12*) automake_progs="automake-1.12" ;;
-esac
-version_check automake AUTOMAKE "$automake_progs" $REQUIRED_AUTOMAKE_VERSION \
-    "http://ftp.gnu.org/pub/gnu/automake/automake-$REQUIRED_AUTOMAKE_VERSION.tar.gz"
-ACLOCAL=`echo $AUTOMAKE | sed s/automake/aclocal/`
-
-if $want_libtool; then
-    version_check libtool LIBTOOLIZE "libtoolize glibtoolize" $REQUIRED_LIBTOOL_VERSION \
-        "http://ftp.gnu.org/pub/gnu/libtool/libtool-$REQUIRED_LIBTOOL_VERSION.tar.gz"
-    require_m4macro libtool.m4
-fi
-
-if $want_gettext; then
-    version_check gettext GETTEXTIZE gettextize $REQUIRED_GETTEXT_VERSION \
-        "http://ftp.gnu.org/pub/gnu/gettext/gettext-$REQUIRED_GETTEXT_VERSION.tar.gz"
-    require_m4macro gettext.m4
-fi
-
 if $want_glib_gettext; then
     version_check glib-gettext GLIB_GETTEXTIZE glib-gettextize $REQUIRED_GLIB_GETTEXT_VERSION \
         "ftp://ftp.gtk.org/pub/gtk/v2.2/glib-$REQUIRED_GLIB_GETTEXT_VERSION.tar.gz"
@@ -426,35 +382,19 @@ for configure_ac in $configure_files; do
 	printbold "Processing $configure_ac"
 	cd $dirname
 
-        # Note that the order these tools are called should match what
-        # autoconf's "autoupdate" package does.  See bug 138584 for
-        # details.
-
-        # programs that might install new macros get run before aclocal
-	if grep "^A[CM]_PROG_LIBTOOL" $basename >/dev/null ||
-	   grep "^LT_INIT" $basename >/dev/null; then
-	    printbold "Running $LIBTOOLIZE..."
-	    $LIBTOOLIZE --force --copy || exit 1
+	# if the AC_CONFIG_MACRO_DIR() macro is used, create that directory
+	# This is a automake bug fixed in automake 1.13.2
+	# See http://debbugs.gnu.org/cgi/bugreport.cgi?bug=13514
+	m4dir=`autoconf --trace 'AC_CONFIG_MACRO_DIR:$1'`
+	if [ -n "$m4dir" ]; then
+	    mkdir -p $m4dir
 	fi
 
 	if grep "^AM_GLIB_GNU_GETTEXT" $basename >/dev/null; then
-	    printbold "Running $GLIB_GETTEXTIZE... Ignore non-fatal messages."
-	    echo "no" | $GLIB_GETTEXTIZE --force --copy || exit 1
-	elif grep "^AM_GNU_GETTEXT" $basename >/dev/null; then
-	   if grep "^AM_GNU_GETTEXT_VERSION" $basename > /dev/null; then
-	   	printbold "Running autopoint..."
-		autopoint --force || exit 1
-	   else
-	    	printbold "Running $GETTEXTIZE... Ignore non-fatal messages."
-	    	echo "no" | $GETTEXTIZE --force --copy || exit 1
-	   fi
+	   printbold "Running $GLIB_GETTEXTIZE... Ignore non-fatal messages."
+	   echo "no" | $GLIB_GETTEXTIZE --force --copy || exit 1
 	fi
 
-	if grep "^AC_PROG_INTLTOOL" $basename >/dev/null ||
-           grep "^IT_PROG_INTLTOOL" $basename >/dev/null; then
-	    printbold "Running $INTLTOOLIZE..."
-	    $INTLTOOLIZE --force --copy --automake || exit 1
-	fi
 	if grep "^GTK_DOC_CHECK" $basename >/dev/null; then
 	    printbold "Running $GTKDOCIZE..."
 	    $GTKDOCIZE --copy || exit 1
@@ -469,54 +409,15 @@ for configure_ac in $configure_files; do
 	    $GNOME_DOC_PREPARE --force --copy || exit 1
 	fi
 
-        # Now run aclocal to pull in any additional macros needed
-
-	# if the AC_CONFIG_MACRO_DIR() macro is used, pass that
-	# directory to aclocal.
-	m4dir=`cat "$basename" | grep '^AC_CONFIG_MACRO_DIR' | sed -n -e 's/AC_CONFIG_MACRO_DIR(\([^()]*\))/\1/p' | sed -e 's/^\[\(.*\)\]$/\1/' | sed -e 1q`
-	if [ -n "$m4dir" ]; then
-	    m4dir="-I $m4dir"
-	fi
-	printbold "Running $ACLOCAL..."
-	$ACLOCAL $m4dir $ACLOCAL_FLAGS || exit 1
-
-	if grep "GNOME_AUTOGEN_OBSOLETE" aclocal.m4 >/dev/null; then
-	    printerr "*** obsolete gnome macros were used in $configure_ac"
+	if grep "^AC_PROG_INTLTOOL" $basename >/dev/null ||
+           grep "^IT_PROG_INTLTOOL" $basename >/dev/null; then
+	    printbold "Running $INTLTOOLIZE..."
+	    $INTLTOOLIZE --force --copy --automake || exit 1
 	fi
 
-	# Now that all the macros are sorted, run autoconf and autoheader ...
-	printbold "Running $AUTOCONF..."
-	$AUTOCONF || exit 1
-	if grep "^A[CM]_CONFIG_HEADER" $basename >/dev/null; then
-	    printbold "Running $AUTOHEADER..."
-	    $AUTOHEADER || exit 1
-	    # this prevents automake from thinking config.h.in is out of
-	    # date, since autoheader doesn't touch the file if it doesn't
-	    # change.
-	    test -f config.h.in && touch config.h.in
-	fi
-
-	# Finally, run automake to create the makefiles ...
-	printbold "Running $AUTOMAKE..."
-        if [ -f COPYING ]; then
-          cp -pf COPYING COPYING.autogen_bak
-        fi
-        if [ -f INSTALL ]; then
-          cp -pf INSTALL INSTALL.autogen_bak
-        fi
-	if [ $REQUIRED_AUTOMAKE_VERSION != 1.4 ]; then
-	    $AUTOMAKE --gnu --add-missing --copy -Wno-portability || exit 1
-	else
-	    $AUTOMAKE --gnu --add-missing --copy || exit 1
-	fi
-        if [ -f COPYING.autogen_bak ]; then
-          cmp COPYING COPYING.autogen_bak > /dev/null || cp -pf COPYING.autogen_bak COPYING
-          rm -f COPYING.autogen_bak
-        fi
-        if [ -f INSTALL.autogen_bak ]; then
-          cmp INSTALL INSTALL.autogen_bak > /dev/null || cp -pf INSTALL.autogen_bak INSTALL
-          rm -f INSTALL.autogen_bak
-        fi
+	# Now that all the macros are sorted, run autoreconf ...
+	printbold "Running autoreconf..."
+	autoreconf --verbose --force --install -Wno-portability || exit 1
 
 	cd "$topdir"
     fi
